package com.gic.message.service.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.constant.AuthModeEnum;
import com.gic.auth.service.UnionEnterpriseApiService;
import com.gic.binlog.base.entity.GicField;
import com.gic.binlog.base.entity.GicRecord;
import com.gic.binlog.base.entity.enums.GicRecordType;
import com.gic.message.service.MessageHandler;
import com.gic.message.utils.ListToMapUtil;
import com.gic.store.constant.StoreOwnTypeEnum;
import com.gic.store.dto.StoreSearchDTO;
import com.gic.store.dto.StoreWidgetDTO;
import com.gic.store.service.StoreApiService;
import com.gic.store.service.StoreWidgetApiService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

@Component
public class StoreMessageHandler implements MessageHandler {
    @Autowired
    private StoreApiService storeApiService;
    @Autowired
    private StoreIndexRefreshHandler storeIndexRefreshHandler;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;
    @Autowired
    private UnionEnterpriseApiService unionEnterpriseApiService;

    @Override
    public void handler(ConsumerRecord<String, GicRecord> consumerRecord){
        GicRecord value = consumerRecord.value();
        Map<String, GicField> fieldMap = ListToMapUtil.listToMap(consumerRecord);
        Integer enterpriseId = 0, storeId = 0;
        if(GicRecordType.INSERT.value() == value.getRecordType().value()){
            enterpriseId = Integer.valueOf(fieldMap.get("enterprise_id").getValue());
            storeId = Integer.valueOf(fieldMap.get("store_id").getValue());
            this.storeIndexRefreshHandler.refreshStoreIndex(enterpriseId, storeId);
            Integer ownType = Integer.valueOf(fieldMap.get("own_type").getValue());
            if(ownType == StoreOwnTypeEnum.OWNER.getCode()){
                ServiceResponse<List<Long>> resourceResponse = this.unionEnterpriseApiService.listStoreResourceByEnterpriseId(enterpriseId);
                if(CollectionUtils.isNotEmpty(resourceResponse.getResult())){
                    for(Long resourceId : resourceResponse.getResult()){
                        ServiceResponse<StoreWidgetDTO> storeWidget = this.storeWidgetApiService.getStoreWidget(resourceId.intValue());
                        if(storeWidget.isSuccess()){
                            StoreWidgetDTO storeWidgetDTO = storeWidget.getResult();
                            if(storeWidgetDTO != null){
                                if(AuthModeEnum.YES.getCode() == storeWidgetDTO.getAuthMode()){
                                    StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
                                    storeSearchDTO.setStoreInfoIds("");
                                }
                            }
                        }
                    }
                }
            }
        }
        if(GicRecordType.UPDATE.value() == value.getRecordType().value()){
            int isAdd = 0;
            if(Integer.valueOf(fieldMap.get("old_status").getValue()) == 0 && Integer.valueOf(fieldMap.get("new_status").getValue()) == 1){
                isAdd = 1;
            }
            if(Integer.valueOf(fieldMap.get("old_status").getValue()) == 1 && Integer.valueOf(fieldMap.get("new_status").getValue()) == 0){
                isAdd = 2;
            }
            enterpriseId = Integer.valueOf(fieldMap.get("new_enterprise_id").getValue());
            storeId = Integer.valueOf(fieldMap.get("new_store_id").getValue());
            if(isAdd != 0){
                if(isAdd == 1){
                    this.storeIndexRefreshHandler.refreshStoreIndex(enterpriseId, storeId);
                }else {
                    this.storeApiService.deleteStoreFromES(enterpriseId, storeId);
                }
             }else {
                 this.storeIndexRefreshHandler.refreshStoreIndex(enterpriseId, storeId);
             }
        }

        if(GicRecordType.DELETE.value() == value.getRecordType().value()){
            enterpriseId = Integer.valueOf(fieldMap.get("enterprise_id").getValue());
            storeId = Integer.valueOf(fieldMap.get("store_id").getValue());
            this.storeApiService.deleteStoreFromES(enterpriseId, storeId);
        }
    }
}
